# compatibility with legacy rpm
%{!?_lib:%define _lib	lib}

%define db_versions 3.1.17 3.2.9
%define	_libdb_a	libdb-${soversion}.a
%define	_libcxx_a	libdb_cxx-${soversion}.a

Summary: The Berkeley DB database library for C.
Name: db3x
Version: 3.2.9
Release: 4
Source0: http://www.sleepycat.com/update/3.1.17/db-3.1.17.tar.gz
Source1: http://www.sleepycat.com/update/3.2.9/db-3.2.9.tar.gz
Patch0: db-3.1.17-tcl.patch
Patch1: patch.3.2.9.1
Patch2: patch.3.2.9.2
Obsoletes: db31
URL: http://www.sleepycat.com/
License: BSDish
Group: System Environment/Libraries
BuildPreReq: findutils, perl, tcl
BuildRoot: %{_tmppath}/%{name}-root
Prefix: %{_prefix}

%description
The Berkeley Database (Berkeley DB) is a programmatic toolkit that provides
embedded database support for both traditional and client/server applications.
Berkeley DB is used by many applications, including Python and Perl, so this
should be installed on all systems.

%package utils
Summary: Command line tools for managing Berkeley DB databases.
Group: Applications/Databases
Requires: %{name} = %{version}
Prefix: %{_prefix}

%description utils
The Berkeley Database (Berkeley DB) is a programmatic toolkit that provides
embedded database support for both traditional and client/server applications.
Berkeley DB includes B+tree, Extended Linear Hashing, Fixed and Variable-length
record access methods, transactions, locking, logging, shared memory caching
and database recovery. DB supports C, C++, Java and Perl APIs.

This package contains command line tools for managing Berkeley DB databases.

%prep
%setup -q -c -a 1

pushd db-3.1.17
%patch0 -p1 -b .tcl
popd

pushd db-3.2.9
%patch1 -p0 -b .1
%patch2 -p0 -b .2
popd

%build
CFLAGS="$RPM_OPT_FLAGS"; export CFLAGS
for version in %{db_versions} ; do
	pushd db-${version}/dist
# XXX --enable-posixmutexes is useful for threads but useless for interprocess locking.
# XXX --enable-diagnostic should be disabled for production (but is useful).
# XXX --enable-debug_{r,w}op should be disabled for production.
# XXX --enable-java
	%configure --prefix=%{_prefix} \
		--enable-compat185 \
		--enable-shared --disable-static \
		--enable-rpc --enable-tcl --with-tcl=%{_libdir} \
		--enable-cxx --enable-test \
		# --enable-diagnostic \
		# --enable-debug --enable-debug_rop --enable-debug_wop \
		# --enable-posixmutexes

	soversion=`echo ${version} | cut -f1,2 -d.`
	make libdb=%{_libdb_a} libcxx=%{_libcxx_a}
	popd
done

# remove dangling tags symlink from examples.
rm -f examples_cxx/tags
rm -f examples_c/tags

%install
rm -rf ${RPM_BUILD_ROOT}
mkdir -p ${RPM_BUILD_ROOT}%{_includedir}
mkdir -p ${RPM_BUILD_ROOT}%{_prefix}/lib

for version in %{db_versions} ; do
	pushd db-${version}/dist
	%makeinstall libdb=%{_libdb_a} libcxx=%{_libcxx_a}
	# Rename the utilities.
	major=`echo ${version} | cut -c1,3`
	for bin in $RPM_BUILD_ROOT/%{_bindir}/*db_* ; do
		t=`echo ${bin} | sed "s,db_,db${major}_,g"`
		mv ${bin} ${t}
	done
	popd
done
# On Linux systems, move the shared libraries to lib directory.
%ifos linux
if [ "%{_libdir}" != "%{_lib}" ]; then
        mkdir -p $RPM_BUILD_ROOT/%{_lib}
        mv $RPM_BUILD_ROOT/%{_libdir}/libdb[-.]*so* $RPM_BUILD_ROOT/%{_lib}/
fi
%endif

%clean
rm -rf ${RPM_BUILD_ROOT}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc db-%{version}/LICENSE db-%{version}/README
%ifos linux
/%{_lib}/libdb-?.?.so
%else
%{_libdir}/libdb-?.?.so
%endif
%{_libdir}/libdb_cxx-?.?.so
%{_libdir}/libdb_tcl-?.?.so
%{_bindir}/berkeley_db*_svc
%{_bindir}/db*_archive
%{_bindir}/db*_checkpoint
%{_bindir}/db*_deadlock
%{_bindir}/db*_dump
%{_bindir}/db*_load
%{_bindir}/db*_printlog
%{_bindir}/db*_recover
%{_bindir}/db*_stat
%{_bindir}/db*_upgrade
%{_bindir}/db*_verify

%changelog
* Thu Mar 28 2002 Nalin Dahyabhai <nalin@redhat.com> 3.2.9-4
- rebuild

* Thu Mar 28 2002 Nalin Dahyabhai <nalin@redhat.com> 3.2.9-3
- don't list the tcl include path before other flags when building libdb_tcl
  3.1.x (tcl is in /usr, so this pulls in /usr/include/db.h, which is wrong)

* Mon Mar 25 2002 Nalin Dahyabhai <nalin@redhat.com> 3.2.9-2
- rebuild

* Mon Mar 25 2002 Nalin Dahyabhai <nalin@redhat.com> 3.2.9-1
- rename to db3x and merge in db 3.1 and db 3.2 compatibility stuffs

* Mon Apr 16 2001 Nalin Dahyabhai <nalin@redhat.com>
- rename to db31, drop the -devel subpackage, merge the -utils package
- remove berkeley_db_svc, libdb_tcl.so (conflicts with current -utils)

* Thu Apr 05 2001 Nalin Dahyabhai <nalin@redhat.com>
- fix URLs in docs for the -utils and -devel subpackages to point to the
  images in the main package's documentation directory (#33328)
- change Copyright: GPL to License: BSDish

* Fri Mar 23 2001 Bill Nottingham <notting@redhat.com>
- turn off --enable-debug

* Tue Dec 12 2000 Jeff Johnson <jbj@redhat.com>
- rebuild to remove 777 directories.

* Sat Nov 11 2000 Jeff Johnson <jbj@redhat.com>
- don't build with --enable-diagnostic.
- add build prereq on tcl.
- default value for %%_lib macro if not found.

* Tue Oct 17 2000 Jeff Johnson <jbj@redhat.com>
- add /usr/lib/libdb-3.1.so symlink to %%files.
- remove dangling tags symlink from examples.

* Mon Oct  9 2000 Jeff Johnson <jbj@redhat.com>
- rather than hack *.la (see below), create /usr/lib/libdb-3.1.so symlink.
- turn off --enable-diagnostic for performance.

* Fri Sep 29 2000 Jeff Johnson <jbj@redhat.com>
- update to 3.1.17.
- disable posix mutexes Yet Again.

* Tue Sep 26 2000 Jeff Johnson <jbj@redhat.com>
- add c++ and posix mutex support.

* Thu Sep 14 2000 Jakub Jelinek <jakub@redhat.com>
- put nss_db into a separate package

* Wed Aug 30 2000 Matt Wilson <msw@redhat.com>
- rebuild to cope with glibc locale binary incompatibility, again

* Wed Aug 23 2000 Jeff Johnson <jbj@redhat.com>
- remove redundant strip of libnss_db* that is nuking symbols.
- change location in /usr/lib/libdb-3.1.la to point to /lib (#16776).

* Thu Aug 17 2000 Jeff Johnson <jbj@redhat.com>
- summaries from specspo.
- all of libdb_tcl* (including symlinks) in db3-utils, should be db3->tcl?

* Wed Aug 16 2000 Jakub Jelinek <jakub@redhat.com>
- temporarily build nss_db in this package, should be moved
  into separate nss_db package soon

* Wed Jul 19 2000 Jakub Jelinek <jakub@redhat.com>
- rebuild to cope with glibc locale binary incompatibility

* Wed Jul 12 2000 Prospector <bugzilla@redhat.com>
- automatic rebuild

* Sun Jun 11 2000 Jeff Johnson <jbj@redhat.com>
- upgrade to 3.1.14.
- create db3-utils sub-package to hide tcl dependency, enable tcl Yet Again.
- FHS packaging.

* Mon Jun  5 2000 Jeff Johnson <jbj@redhat.com>
- disable tcl Yet Again, base packages cannot depend on libtcl.so.

* Sat Jun  3 2000 Jeff Johnson <jbj@redhat.com>
- enable tcl, rebuild against tcltk 8.3.1 (w/o pthreads).

* Tue May 30 2000 Matt Wilson <msw@redhat.com>
- include /lib/libdb.so in the devel package

* Wed May 10 2000 Jeff Johnson <jbj@redhat.com>
- put in "System Environment/Libraries" per msw instructions.

* Tue May  9 2000 Jeff Johnson <jbj@redhat.com>
- install shared library in /lib, not /usr/lib.
- move API docs to db3-devel.

* Mon May  8 2000 Jeff Johnson <jbj@redhat.com>
- don't rename db_* to db3_*.

* Tue May  2 2000 Jeff Johnson <jbj@redhat.com>
- disable --enable-test --enable-debug_rop --enable-debug_wop.
- disable --enable-posixmutexes --enable-tcl as well, to avoid glibc-2.1.3
  problems.

* Mon Apr 24 2000 Jeff Johnson <jbj@redhat.com>
- add 3.0.55.1 alignment patch.
- add --enable-posixmutexes (linux threads has not pthread_*attr_setpshared).
- add --enable-tcl (needed -lpthreads).

* Sat Apr  1 2000 Jeff Johnson <jbj@redhat.com>
- add --enable-debug_{r,w}op for now.
- add variable to set shm perms.

* Sat Mar 25 2000 Jeff Johnson <jbj@redhat.com>
- update to 3.0.55

* Tue Dec 29 1998 Jeff Johnson <jbj@redhat.com>
- Add --enable-cxx to configure.

* Thu Jun 18 1998 Jeff Johnson <jbj@redhat.com>
- Create.
